# unihiker
This is a library for unihiker M10 from DFRobot (https://www.unihiker.com). Now there is an easy-to-use GUI inside based on tkinter and ttkbootstrap. This library aims to make unihiker suitable for education scenario.
The parameters in GUI's function is highly compatible with Tkinter's Button and Canvas widget. You could find the reference from here to get the detail configuration and parameters:
https://anzeljg.github.io/rin2/book2/2405/docs/tkinter/canvas.html
https://anzeljg.github.io/rin2/book2/2405/docs/tkinter/button.html

## Notice

Note: This library is developed solely to support the unihiker M10 system and does not guarantee compatibility with other systems and hardware.
